pub fn request_authorization()Expand description
Request notification authorization from the OS. On macOS this triggers the permission prompt on first call. No-op on other platforms.
pub fn request_authorization()Request notification authorization from the OS. On macOS this triggers the permission prompt on first call. No-op on other platforms.